//-----------------------------------------------------
// EA DSP-7S04B 
// 
//
// Ian Harris 2013
// www.embeddedadventures.com
//
//-----------------------------------------------------


// Pic Pack includes
#include "config.h"
#include "pic_utils.h"
#include "pic_serial.h"

// System includes
#include "string.h"
#include "stdlib.h"
#include "config.h"
#include "pic_term.h"
#include "i2c.h"
#include "ea_dsp7s04b.h"

uns8 test_mode = 0;
uns8 colon = 0;
uns8 dots = 0;
uns8 raw = 0;
// Interrupt routine - - - - - - - - - -

void interrupt() {
	
		serial_handle_tx_isr();
		serial_handle_rx_isr();
}

//
// term_entry_callback will be called when 
// user pressed <enter> on serial "terminal".
// term_buffer contains the characters (if any)
// that the user has entered.

void term_entry_callback(uns8 *term_buffer) {

uns8 data[5];
uns8 first_char;
	
	first_char = term_buffer[0];

	switch (first_char) {
		case 'c':
			if (colon) {
				ea_dsp7s04b_clear_colon();
				colon = 0;
			} else {
				ea_dsp7s04b_set_colon();
				colon = 1;
			}
			break;
		case 't':
			if (test_mode) {
				ea_dsp7s04b_test_mode(0);
				test_mode = 0;
			} else {
				ea_dsp7s04b_test_mode(1);
				test_mode = 1;
			}
			break;
		case 'n':
			ea_dsp7s04b_print_str("1234");
			break;
		case 'r':
			if (raw) {
				ea_dsp7s04b_put_raw(0, 0x0000);
				ea_dsp7s04b_put_raw(1, 0x0000);
				ea_dsp7s04b_put_raw(2, 0x0000);
				ea_dsp7s04b_put_raw(3, 0x0000);
				raw = 0;
			} else {
				ea_dsp7s04b_put_raw(0, 0b1010101010101010);
				ea_dsp7s04b_put_raw(1, 0b1010101010101010);
				ea_dsp7s04b_put_raw(2, 0b1010101010101010);
				ea_dsp7s04b_put_raw(3, 0b1010101010101010);
				raw = 1;
			}			
			break;		
		case 'l':
			ea_dsp7s04b_clear();
			break;
		case 'e':
			ea_dsp7s04b_set_level(50);
			break;
		case 'p':
			for (uns8 count = 255; count > 0; count--) {
				ea_dsp7s04b_set_level(count);
				delay_ms(20);
			}
			delay_ms(100);
			for (uns8 count = 0; count < 255; count++) {
				ea_dsp7s04b_set_level(count);
				delay_ms(20);
			}	
			break;
		case 'd':
			if (dots) {
				ea_dsp7s04b_clear_dot(0);
				ea_dsp7s04b_clear_dot(1);
				ea_dsp7s04b_clear_dot(2);
				ea_dsp7s04b_clear_dot(3);
				dots = 0;
			} else {
				ea_dsp7s04b_set_dot(0);
				ea_dsp7s04b_set_dot(1);
				ea_dsp7s04b_set_dot(2);
				ea_dsp7s04b_set_dot(3);
				dots = 1;
			}			
			break;
		default:
			serial_print_str("Unknown command.\n");
			break;
	}	// switch		

}	// term_entry_callback


// configure_system
//
// Get the pic ready for everything we want to do

void configure_system() {
	
	// turn off interrupts just in case
	kill_interrupts();
	
	// kill those pesky analogue inputs
	turn_analog_inputs_off();	
	
	// set serial to run at 9600bps 
	serial_setup(SPBRG_115200);
	
	// initialise termainl
	term_init();
	
	ea_dsp7s04b_init();

	// tern peripheral interrupts on (ie, serial port)
	turn_peripheral_ints_on();
	
	// turn all interrupts on
	turn_global_ints_on();
}



void main() {

	configure_system();
	
	delay_ms(100);	// mostly so screamer bootloader has time to switch windows
	
	serial_print_str("\n\nDSP-7S04B Demo (I2C)\n");
	serial_print_str( "\n<");
	
	// Print the time and date this file was compiled. Handy to know which
	// version you are running.
	
	serial_print_str(__TIME__);
	serial_putc(' ');
	serial_print_str(__DATE__);
	serial_print_str(">\n");

	serial_print_str("Commands:\n");
	serial_print_str("d - toggle dots\n");
	serial_print_str("c - toggle colon\n");
	serial_print_str("t - toggle test mode\n");
	serial_print_str("n - print some numbers\n");
	serial_print_str("r - set alternate pixels via raw command\n");
	serial_print_str("Commands:\n");
	

	// a,x,c,n just press the key and enter
	// s00 sets the variable "my_var" to the hex value you enter


	for(;;) {

		term_process();
	
	}

	
}	// main

